@@ -27,6 +27,7 @@ import urllib
 import urllib2
 import gtk
 import time
+import math
 from configobj import ConfigObj
 from tilenames import *
 sys.path.append("modules/pyrender")
@@ -97,6 +98,7 @@ class mapTiles(ranaModule):
     self.imagesQueue = [] #a chronological list of loaded images
     self.threads = {}
     self.maxImagesInMemmory = 100 # to avoid a memmory leak
+    self.tileSide = 256 # by default, the tiles are squares, side=256
     """ TODO: analyse memmory usage,
               set approrpiate value,
               platform dependendt value,
@@ -121,28 +123,53 @@ class mapTiles(ranaModule):
 
   def drawMap(self, cr):
     """Draw map tile images"""
-    (sx,sy,sw,sh) = self.get('viewport')
-    
-    z = int(self.get('z', 15))
-
     proj = self.m.get('projection', None)
     if(proj == None):
       return
     if(not proj.isValid()):
       return
 
-    (px1,px2,py1,py2) = (proj.px1,proj.px2,proj.py1,proj.py2)
+    (sx,sy,sw,sh) = self.get('viewport') # get screen parameters
+    
+    scale = int(self.get('mapScale', 1)) # get the current scale
+    if scale == 1: # this will be most of the time, so it is first
+      z = int(self.get('z', 15))
+      (px1,px2,py1,py2) = (proj.px1,proj.px2,proj.py1,proj.py2) #use normal projection bbox
+      cleanProjectionCoords = (px1,px2,py1,py2) # wee need the unmodified coords for later use
+    else:
+      if scale == 2: # tiles are scaled to 512*512 and represent tiles from zl-1
+        z = int(self.get('z', 15)) - 1
+      elif scale == 4: # tiles are scaled to 1024*1024 and represent tiles from zl-2
+        z = int(self.get('z', 15)) - 2
+      else:
+        z = int(self.get('z', 15))
+
+      # we use tiles from an upper zl and strech them over lower zl
+      (px1,px2,py1,py2) = proj.findEdgesForZl(z, scale)
+      cleanProjectionCoords = (px1,px2,py1,py2) # wee need the unmodified coords for later use
+
+    if self.get("rotateMap", False) and (self.get("centred", False)):
+      # due to the rotation, the map must be larger
+      # we take the longest side and render tiles in a square
+      longestSide = max(sw,sh)
+      add = (longestSide/2)/(self.tileSide)
+      # enlarge the bounding box
+      (px1,px2,py1,py2) = (px1-add,px2+add,py1-add,py2+add)
+
+    # get the range of tiles we need
+    wTiles =  len(range(int(floor(px1)), int(ceil(px2)))) # how many tiles wide
+    hTiles =  len(range(int(floor(py1)), int(ceil(py2)))) # how many tiles high
 
     # upper left tile
     cx = int(px1)
     cy = int(py1)
+    # we need the "clean" cooridnates for the folowing conversion
+    (px1,px2,py1,py2) = cleanProjectionCoords
+    (pdx, pdy) = (px2 - px1,py2 - py1)
     # upper left tile coodinates to screen coordinates
-    cx1,cy1 = proj.pxpy2xy(cx,cy)
+    cx1,cy1 = (sw*(cx-px1)/pdx,sh*(cy-py1)/pdy) #this is basically the pxpy2xy function from mod_projection inlined
     cx1,cy1 = int(cx1),int(cy1)
 
-    wTiles =  len(range(int(floor(px1)), int(ceil(px2)))) # how many tiles wide
-    hTiles =  len(range(int(floor(py1)), int(ceil(py2)))) # how many tiles high
-
     layer = self.get('layer','osma')
     # Cover the whole map view with tiles
 
@@ -161,14 +188,14 @@ class mapTiles(ranaModule):
           y = cy+iy
 
           # get screen coordinates by incrementing upper left tile screen coordinates
-          x1 = cx1 + 256*ix
-          y1 = cy1 + 256*iy
+          x1 = cx1 + 256*ix*scale
+          y1 = cy1 + 256*iy*scale
 
           # Try to load and display images
           nameBack = self.loadImage(x,y,z,layer2)
           nameOver = self.loadImage(x,y,z,layer)
           if(nameBack and nameOver != None):
-            self.drawCompositeImage(cr,nameOver,nameBack,x1,y1,alpha1,alpha2)
+            self.drawCompositeImage(cr,nameOver,nameBack,x1,y1,scale,alpha1,alpha2)
       return
 
 
@@ -181,13 +208,13 @@ class mapTiles(ranaModule):
         y = cy+iy
 
         # get screen coordinates by incrementing upper left tile screen coordinates
-        x1 = cx1 + 256*ix
-        y1 = cy1 + 256*iy
+        x1 = cx1 + 256*ix*scale
+        y1 = cy1 + 256*iy*scale
 
         # Try to load and display images
         name = self.loadImage(x,y,z,layer)
         if(name != None):
-          self.drawImage(cr,name,x1,y1)
+          self.drawImage(cr,name,x1,y1,scale)
 
 
 
@@ -270,7 +297,7 @@ class mapTiles(ranaModule):
     # make sure its removed from the queue
     self.removeNonexistingFromQueue()
   
-  def drawImage(self,cr, name, x,y):
+  def drawImage(self,cr, name, x, y, scale):
     """Draw a tile image"""
     
     # If it's not in memory, then stop here
@@ -281,6 +308,7 @@ class mapTiles(ranaModule):
     # Move the cairo projection onto the area where we want to draw the image
     cr.save()
     cr.translate(x,y)
+    cr.scale(scale,scale) # scale te tile accorind to current scale settings
     
     # Display the image
     cr.set_source_surface(self.images[name],0,0)
@@ -290,7 +318,7 @@ class mapTiles(ranaModule):
     # Return the cairo projection to what it was
     cr.restore()
 
-  def drawCompositeImage(self,cr, nameOver, nameBack, x,y, alpha1=1, alpha2=1):
+  def drawCompositeImage(self,cr, nameOver, nameBack, x,y, scale, alpha1=1, alpha2=1):
     """Draw a composited tile image"""
 
     # If it's not in memory, then stop here
@@ -301,6 +329,7 @@ class mapTiles(ranaModule):
     # Move the cairo projection onto the area where we want to draw the image
     cr.save()
     cr.translate(x,y)
+    cr.scale(scale,scale) # scale te tile accorind to current scale settings
 
     # Display the image
     cr.set_source_surface(self.images[nameBack],0,0) # draw the background
